@@ -169,7 +169,6 @@ module Rake
           make_command_line << "install"
           make_command_line << "sitearchdir=#{relative_lib_path}"
           make_command_line << "sitelibdir=#{relative_lib_path}"
-          make_command_line << "INSTALL_PROG=/usr/bin/install -c -m 0755" unless Process.uid == 0
           make_command_line << "target_prefix="
 
           sh(*make_command_line, chdir: tmp_path)
@@ -279,6 +278,16 @@ Java extension should be preferred.
             "< #{ruby_api_version(sorted_ruby_versions.last).succ}.dev"
           ]
 
+          # set rubygems version constraints
+          if Gem::Version.new(Gem::VERSION) >= Gem::Version.new("3.3.22") &&
+             spec.platform.os == "linux" && !spec.platform.version.nil?
+            spec.required_rubygems_version = if spec.required_rubygems_version == Gem::Requirement.default
+              [">= 3.3.22"]
+            else
+              Gem::Requirement.new(gem_spec.required_rubygems_version, ">= 3.3.22")
+            end
+          end
+
           # clear the extensions defined in the specs
           spec.extensions.clear
 
@@ -430,7 +439,7 @@ Java extension should be preferred.
           f.puts("require 'rbconfig'")
           f.puts("original_enable_shared = RbConfig::CONFIG['ENABLE_SHARED']")
           f.puts(fake_rb(for_platform, ruby_ver))
-          f.puts(File.read(t.prerequisites.first))
+          f.puts("require #{t.prerequisites.first.dump}")
           f.puts("RbConfig::CONFIG['ENABLE_SHARED'] = original_enable_shared")
         end
       end
@@ -495,7 +504,20 @@ Java extension should be preferred.
     end
 
     def make
-      @make ||= ENV['MAKE'] || 'make'
+      unless @make
+        @make =
+          if RUBY_PLATFORM =~ /mswin/ then
+            'nmake'
+          else
+            ENV['MAKE'] || find_make
+          end
+      end
+
+      unless @make
+        raise "Couldn't find a suitable `make` tool. Use `MAKE` env to set an alternative."
+      end
+
+      @make
     end
 
     def find_make
